@@ -1,4 +1,7 @@
-#!/usr/bin/env python
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
+#!/usr/bin/env python3
 import argparse
 import logging
 import os
@@ -103,7 +106,7 @@ class NetscalerConverter(AviConverter):
 
         if is_download_from_host:
             LOG.debug("Copying files from host")
-            print "Copying Files from Host..."
+            print("Copying Files from Host...")
             scp_util.get_files_from_ns(input_dir, self.ns_host_ip,
                                        self.ns_ssh_user, self.ns_ssh_password)
             LOG.debug("Copied input files")
@@ -111,7 +114,7 @@ class NetscalerConverter(AviConverter):
         else:
             source_file = self.ns_config_file
         if not source_file:
-            print 'Not found ns configuration file'
+            print('Not found ns configuration file')
             return
         ns_config, skipped_cmds = ns_parser.get_ns_conf_dict(source_file)
         user_ignore = {}
@@ -378,5 +381,5 @@ if __name__ == "__main__":
         netscaler_converter.print_pip_and_controller_version()
         exit(0)
     netscaler_converter.convert()
-    print "Total Warning: ", get_count('warning')
-    print "Total Errors: ", get_count('error')
+    print("Total Warning: ", get_count('warning'))
+    print("Total Errors: ", get_count('error'))
