@@ -1,7 +1,10 @@
-#!/usr/bin/env python
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
+#!/usr/bin/env python3
 import os
 
-from ConfigParser import ConfigParser
+from configparser import ConfigParser
 
 
 def set_output_dir_in_test_config_ini(ini_file, section, output_dir,
